@@ -1,10 +1,5 @@
 package WWW::Chain;
-BEGIN {
-  $WWW::Chain::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $WWW::Chain::VERSION = '0.003';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: A web request chain
 
 our $VERSION ||= '0.000';
@@ -114,6 +109,7 @@ sub next_responses {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -122,7 +118,7 @@ WWW::Chain - A web request chain
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -150,7 +146,7 @@ version 0.003
 
     sub first_request {
       $_[0]->stash->{a} = 1;
-      return HTTP::Request->new( GET => 'http://duckduckgo.com/' ), "second_request";
+      return HTTP::Request->new( GET => 'http://conflict.industries/' ), "second_request";
     }
 
     sub second_request {
@@ -159,7 +155,7 @@ version 0.003
     }
   }
 
-  my $chain = TestWWWChainMethods->new(HTTP::Request->new( GET => 'http://duckduckgo.com/' ), 'first_request');
+  my $chain = TestWWWChainMethods->new(HTTP::Request->new( GET => 'http://conflict.industries/' ), 'first_request');
 
   # Blocking usage:
 
@@ -193,4 +189,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
